==> dhall-yaml-1.2.11-174-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-yaml
version:              1.2.11
visibility:           public
id:                   dhall-yaml-1.2.11-HF4rJniY2ZYL7n6bn52DDG
key:                  dhall-yaml-1.2.11-HF4rJniY2ZYL7n6bn52DDG
license:              GPL-3.0-only
copyright:            2019 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  1a85ab005479d9f6d10a1acbee6614f2
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.11-HF4rJniY2ZYL7n6bn52DDG
depends:
    HsYAML-0.2.1.3-7Ptv7lWKLyWGPx96OoIlyb
    HsYAML-aeson-0.2.0.1-DJRoaNsymofHD6ZVk3jfRM
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    bytestring-0.11.4.0 dhall-1.41.2-DxjlnSEJkR2FDPUb7caFHV
    dhall-json-1.7.11-EWLnfnBejeW7oGb67dhp5b
    optparse-applicative-0.17.1.0-H9wWDnSwLoeC3JH97ZHNAY text-1.2.5.0
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.11-194-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-yaml
version:              1.2.11
visibility:           public
id:                   dhall-yaml-1.2.11-FfbK9yyK7YkCoIef9aUtsi
key:                  dhall-yaml-1.2.11-FfbK9yyK7YkCoIef9aUtsi
license:              GPL-3.0-only
copyright:            2019 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  07b19a519c55e741ac92785199e1f35e
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-yaml-1.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.11-FfbK9yyK7YkCoIef9aUtsi
depends:
    HsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
    HsYAML-aeson-0.2.0.1-CNax88AhoY87SJVK1EidZj
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 dhall-1.41.2-8joxPp720UY4JPqJUZgc6y
    dhall-json-1.7.11-2LsvBtAJo63BkSTJkaPw4R
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb text-1.2.5.0
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
